define([
	"dojo/_base/declare",

	"aps/xhr",
	"aps/Memory",
	"aps/Tile",
	"aps/nav/ViewPlugin",
	"aps/Output",
	"aps/FieldSet"
], function (
	declare,

	xhr,
	Memory,
	Tile,
	ViewPlugin,
	Output,
	FieldSet
) {
 
	function removeDomain(tile, domainApsId) {
		tile.set("isBusy", true);
		return xhr('/aps/2/resources/' + domainApsId, {
			method: 'DELETE'
		})
		.then(function () {
			tile.removeAll();
			tile.set({
				onClick: function() {
					aps.apsc.gotoView("http://www.parallels.com/ccp-domains#domains");
				},
				isBusy: false
			});
			tile.addChild(new Output({"value": "Click to return to Domains"}));
		});
	}

	return declare(ViewPlugin, {

		init: function (mediator) {
			mediator.setServiceData = function (data) {

				/* Initialize internal variables */
				var vpses = new Memory({
					data: [],
					idProperty: "aps.id"
				});

				var domainData = {
						serviceName: "Virtual Server",
						domainApsId: data.aps.id,
						domainName: data.name,
						status: "Not Assigned"
				};
				
				/* Initialize the tile */
				var tile = new Tile({
					title: domainData.serviceName,
					onClick: function() {
						aps.apsc.gotoView("http://aps-standard.org/samples/dns#server-new-1", null, domainData);
					}
				});

				/* Fill in the tile with the list of assigned servers */
				tile.addChild(new Output({
					value: "Click to host a VPS on this domain"
				}));
 
				if (!data.services || data.services.length === 0) {
					return tile;
				}
 
				data.services.forEach(function (service) {
					if(service.aps.type === "http://aps-standard.org/samples/dns/vps/1.0") {
						vpses.data.push(service);
					}
				});
				if (vpses.data.length > 0) {
					domainData.status = "Assigned";
					var container = new FieldSet({title: "Assigned services: "});
					vpses.data.forEach( function(vps) {
						container.addChild(new Output({
							content: "VPS name: ${value}",
							value: vps.name
						}));
					});
					tile.addChild(container);
					
					/* Add the menu to the tile */
					tile.set("buttons", [
						{
							icon: "fa-times-circle",
							label: "Go to VPS list",
							onClick: function () {
								aps.apsc.gotoView("http://aps-standard.org/samples/dns#servers", null, domainData);
							}
						},
						{
							icon: "fa-times-circle",
							label: "Remove domain",
							onClick: function () {
								removeDomain(tile, domainData.domainApsId);
							}
						}
					]);
				}
				return tile;
			};
		}
	});
});
