define([
	"dojo/_base/declare",
	"dojo/when",
	"dojox/mvc/getPlainValue",
	"dojox/mvc/at",
	"dojox/mvc/getStateful",

	"aps/_View",
	"aps/ResourceStore",

	"./displayError",

	"dojo/text!./newvps.json"
], function (
	declare,
	when,
	getPlainValue,
	at,
	getStateful,

	_View,
	Store,

	displayError,

	newVPS
) {
	return declare(_View, {
		init: function () {
			/* Declare data sources */
			this.store = new Store({
				target: "/aps/2/resources"
			});
			aps.app.model.set("editVPS", getStateful(JSON.parse(newVPS)));
			
			/* Declare widgets */
			return ["aps/Container", {
					id: "edit_form"
				}, [
					["aps/Panel", {
						id: "srvNew1_virtual_server_general",
						title: _("Virtual Server")
					},
						[
							["aps/FieldSet", {
									id: "edit_general"
								},[
									["aps/TextBox", {
										id: "edit_serverName",
										gridSize: 'md-3 xs-12',
										label: _("Server Name"),
										value: at(aps.app.model.editVPS, "name"),
										required: true
									}],
									["aps/TextBox", {
										id: "edit_description",
										gridSize: 'md-3 xs-12',
										label: _("Description"),
										value: at(aps.app.model.editVPS, "description")
									}]
							]]
						]
					],
				["aps/Panel", {
						id: "srvNew1_virtual_server_props",
						title: _("Server Configuration")
					},
					[
						["aps/FieldSet", {
								id: "edit_props"
							},
							[
								["aps/Spinner", {
									id: "edit_cpu",
									gridSize: 'md-3 xs-12',
									label: _( "CPU Number"),
									minimum: 1,
									maximum: 16,
									value: at(aps.app.model.editVPS.hardware.CPU, "number"),
									step: 1
								}],
								["aps/Spinner", {
									id: "edit_disk",
									gridSize: 'md-3 xs-12',
									label: _("Disk Space"),
									minimum: 1,
									maximum: 100,
									value: at(aps.app.model.editVPS.hardware, "diskspace"),
									legend: _("Gb"),
									step: 1
								}],
								["aps/Spinner", {
									id: "edit_ram",
									gridSize: 'md-3 xs-12',
									label: _("RAM"),
									minimum: 128,
									maximum: 8192,
									value: at(aps.app.model.editVPS.hardware, "memory"),
									legend: _("Mb"),
									step: 128
								}]
							]
						]
					]
				]
			]];
		},
		/* Create handlers for the navigation buttons */
		onCancel: function() {
			aps.apsc.gotoView("servers");
		},
		
		onSubmit: function() {
			var form = this.byId("edit_form");
			if (!form.validate()) {
				aps.apsc.cancelProcessing();
				return;
			}
			when(this.store.put(getPlainValue(aps.app.model.editVPS)),
				function() {
					aps.apsc.gotoView("servers");
				},
				displayError
			);
		},

		onContext: function() {
			/* Getting VPS properties */
			this.store.get(aps.context.vars.vps.aps.id).then(function(vps) {
				/* Collect the VPS properties in the model */
				aps.app.model.set("editVPS", getStateful(vps));
				aps.apsc.hideLoading(); /* Mandatory call */
			});
		},

		onHide: function() {
			/* Reset widget fields to avoid flickering when opening another VPS */
			aps.app.model.set("editVPS", getStateful(JSON.parse(newVPS)));
		}

  });
});
