define([
	"dojo/_base/declare",
	"dojox/mvc/getPlainValue",
	"dojox/mvc/at",
	"dojox/mvc/getStateful",

	"aps/_View",
	"aps/Memory",
	"aps/ResourceStore",

	"dojo/text!./newvps.json"
], function (
	declare,
	getPlainValue,
	at,
	getStateful,

	_View,
	Memory,
	Store,

	newVPS
) {
		return declare(_View, {
			init: function() {
				/* Declare the data sources */
				var oses = new Memory({
					idProperty: "value",
					data: [
						{ value: "centos6",      label: "CentOS 6" },
						{ value: "debian",       label: "Debian" },
						{ value: "windows2008",  label: "Windows 2008 Server" },
						{ value: "windows2012",  label: "Windows 2012 Server" }
					]
				});

				this.domainStore = new Memory({
					data: [],
					idProperty: "aps.id"
				});
				
				aps.app.model.set("newVPS", getStateful(JSON.parse(newVPS)));
				
				/* Declare widgets */
				return ["aps/Container", {
						id: "srvNew1_form"
					},
					[
						["aps/Panel", {
								id: "srvNew1_page",
								title: _("Virtual Server")
							},
							[
								["aps/FieldSet", [
									["aps/TextBox", {
										id: "srvNew1_serverName",
										gridSize: 'md-3 xs-12',
										label: _("Server Name"),
										value: at(aps.app.model.newVPS, "name"),
										required: true
									}],
									["aps/TextBox", {
										id: "srvNew1_description",
										gridSize: 'md-3 xs-12',
										label: _("Description"),
										value: at(aps.app.model.newVPS,
											"description")
									}]
								]]
							]
						],
						["aps/Panel", {
							id: "srvNew1_configuration",
							title: _("Server Configuration")
						},
							[
								["aps/FieldSet", {
									id: "srvNew1_"
								},
									[
										["aps/Select", {
											id: "srvNew1_os",
											gridSize: 'md-3 xs-12',
											label: _("OS"),
											value: at(aps.app.model.newVPS.platform.OS, "name"),
											store: oses
										}],
										["aps/Spinner", {
											id: "srvNew1_cpu",
											gridSize: 'md-3 xs-12',
											label: _("CPU Number"),
											minimum: 1,
											maximum: 16,
											value: at(aps.app.model.newVPS.hardware.CPU, "number"),
											step: 1
										}],
										["aps/Spinner", {
											id: "srvNew1_disk",
											gridSize: 'md-3 xs-12',
											label: _("Disk Space"),
											minimum: 1,
											maximum: 100,
											value: at(aps.app.model.newVPS.hardware, "diskspace"),
											legend: _("Gb"),
											step: 1
										}],
										["aps/Spinner", {
											id: "srvNew1_ram",
											gridSize: 'md-3 xs-12',
											label: _("RAM"),
											minimum: 128,
											maximum: 8192,
											value: at(aps.app.model.newVPS.hardware, "memory"),
											step: 128,
											legend: _("Mb")
										}]
									]
								]
							]
						],
						["aps/Panel", {
								id: "srvNew1_select_domain",
								title: _("Select Domain")
							},
							[
								["aps/FieldSet", {
										id: "srvNew1_domains"
									},
									[
										["aps/Select", {
											id: "srvNew1_domainSelect",
											gridSize: 'md-3 xs-12',
											store: this.domainStore,
											labelAttr: "name",
											value: at(aps.app.model.newVPS.domain.aps, "id")
										}],
										["aps/CheckBox", {
											id: "srvNew1_domainCname",
											gridSize: 'md-3 xs-12',
											description: _('CNAME record'),
											checked: at(aps.app.model.newVPS, "cnameRecord")
										}]
									]
								]
							]
						]
					]
				];
			},

			/* Create handlers for the navigation buttons */
			onCancel: function() {
				aps.apsc.gotoView("servers");
			},
			
			onNext: function() {
				var domainName = this.byId("srvNew1_domainSelect").getOption(aps.app.model.newVPS.domain.aps.id)[0].label;
				aps.app.model.newVPS.set("domainName", domainName);
				/* Proceed to the next screen */
				aps.apsc.gotoView("server-new-last");
			},
			
			onShow: function() {
				if (aps.app.isNew !== false)
					aps.app.model.set("newVPS", JSON.parse(newVPS));
			},

			onContext: function() {
				var store = new Store({
					target: "/aps/2/resources/",
					apsType: "http://aps-standard.org/types/dns/zone/1.0"
				});

				/* Refresh the store */
				store.query().then(function (domains) {
					this.domainStore.setData(domains);
					var domainSelection = this.byId("srvNew1_domainSelect");
					domainSelection.set("store", this.domainStore);
					var selectedDomainApsId = (aps.context.params.domainApsId) ? aps.context.params.domainApsId : domains[0].aps.id;
					domainSelection.set("value", selectedDomainApsId);
					aps.apsc.hideLoading();
				}.bind(this));
			},
			onHide: function() {
				delete aps.app.isNew;
			}
		});
});
