define([
	"dojo/_base/declare",
	"dojo/when",
	"dojox/mvc/getPlainValue",
	"dojox/mvc/at",

	"aps/_View",
	"aps/xhr",
	"aps/ResourceStore"
], function(
	declare,
	when,
	getPlainValue,
	at,

	_View,
	xhr,
	Store
) {
	var cNameNeeded = "false";

	function createDnsRecord(vps, domain) {
		var jsonData = {
			"aps": {
				"type": "http://aps-standard.org/types/dns/record/cname/1.0"
			},
			"RRState": "active",
			"TTL": 3600,
			"source": vps.name + "." + domain + ".",
			"cname": "a." + domain + ".",
			"zone": {
				"aps": {
					"id": vps.domain.aps.id
				}
			}
		};
		return xhr("/aps/2/resources/" + vps.aps.id + "/records", {
			method: "POST",
			data: JSON.stringify(jsonData)
		});
	}

	return declare(_View, {
		init: function() {
			/* Create widgets */
			return ["aps/Panel", {
				id: "srvNew_page"
			},
				[
					["aps/FieldSet", {
						id: "srvNew_general",
						title: "General"
					},
						[
							["aps/Output", {
								id: "srvNew_serverName",
								label: "Server Name",
								value: at(aps.app.model.newVPS, "name")
							}],
							["aps/Output", {
								id: "srvNew_description",
								label: "Description",
								value: at(aps.app.model.newVPS, "description")
							}]
						]
					],
					["aps/FieldSet", {
						id: "srvNew_props",
						title: "Server Configuration"
					},
						[
							["aps/Output", {
								id: "srvNew_os",
								label: "OS",
								value: at(aps.app.model.newVPS.platform.OS, "name")
							}],
							["aps/Output", {
								id: "srvNew_cpu",
								label: "CPU",
								value: at(aps.app.model.newVPS.hardware.CPU, "number")
							}],
							["aps/Output", {
								id: "srvNew_disk",
								label: "Disk Space",
								value: at(aps.app.model.newVPS.hardware, "diskspace")
							}],
							["aps/Output", {
								id: "srvNew_ram",
								label: "RAM",
								value: at(aps.app.model.newVPS.hardware, "memory")
							}],
							["aps/Output", {
								id: "srvNew_domain",
								label: "Domain",
								value: at(aps.app.model.newVPS, "domainName")
							}],
							["aps/Status", {
								id: "srvNew_cName",
								label: "CNAME",
								status: cNameNeeded,
								useIcon: true,
								statusInfo: {
									"no": {
										"label": "",
										"type": "disabled",
										"icon": "fa-minus"
									},
									"yes": {
										"label": "",
										"type": "success",
										"icon": "fa-check"
									}
								}
							}]
						]
					]
				]
			];
		},

		/* Create handlers for the navigation buttons */
		onSubmit: function() {
			aps.context.subscriptionId = aps.context.vars.context.aps.subscription;

			/* Declare data sources */
			var store = new Store({
				apsType: "http://aps-standard.org/samples/dns/vps/1.0",
				target: "/aps/2/resources/" + aps.context.vars.context.aps.id + "/vpses"
			});

			store.put(getPlainValue(aps.app.model.newVPS))
				.then(function(vps) {
					if (aps.app.model.newVPS.cnameRecord)
						return createDnsRecord(vps, aps.app.model.newVPS.domainName);
				})
				.then(function() {
					aps.apsc.gotoView("servers");
				});
		},

		onPrev: function() {
			aps.app.isNew = false;
			aps.apsc.gotoView("server-new-1");
		},

		onContext: function() {
			cNameNeeded = (aps.app.model.newVPS.get("cnameRecord")) ? "yes" : "no";
			this.byId("srvNew_cName").set("status", cNameNeeded);
			aps.apsc.hideLoading();
		}

	}); // End of Declare
}); // End of Define