define([
	"dojo/_base/declare",
	"dojo/when",

	"aps/_View",
	"aps/ResourceStore",
	"aps/Status",

	"./displayError"
], function (
	declare,
	when,

	_View,
	Store,
	Status,

	displayError
) {
	return declare(_View, {
		init: function() {
			var self = this;

			/* Create the data store */
			var store = new Store({
				apsType: "http://aps-standard.org/samples/dns/vps/1.0",
				target: "/aps/2/resources/"
			});

			/* Create a handler for the *New* button click */
			var add = function() {
				/* Start the process of creating a VPS by going to the first screen */
				aps.apsc.gotoView("server-new-1");
			};

			var refresh = function() {
				self.grid.refresh();
			};

			function changeState(state, btn){
				var sel = self.grid.get("selectionArray"),
				counter = sel.length;

				/* Clear the current messages on the screen */
				self.page.get("messageList").removeAll();

				sel.forEach(function(vpsId){
					console.log("I'm trying to change state of VPS with id = [" + vpsId + "]");

					var vps = {
						aps: { id: vpsId },
						state: state
					};

					/* Save the VPS properties */
					when(store.put(vps),
						 /* If success, process the next VPS until the list is empty */
						function(){
							console.log("State of VPS with id = [" + vpsId + "] changed");
							sel.splice(sel.indexOf(vpsId),1);
							self.grid.refresh();
							if (--counter === 0) { btn.cancel(); } /* Remove busy state for button */
						},
						/* If failure, call the error handler */
						function(e){
							displayError(e);
							if (--counter === 0) { btn.cancel(); }
						}
					);
				});
			}

			/* Create the on-click handler for the *Stop* button */
			var stop = function() {
				changeState("Stopped", this);
			};

			/* Create the on-click handler for the *Start* button */
			var start = function() {
				changeState("Running", this);
			};

			/* Create the on-click handler for the *Delete* button */
			var remove = function() {
				var btn = this;
				/* Get confirmation from the user for the delete operation */
				if (!confirm("Are you sure you want delete VPSes?")) {
					btn.cancel();
					return;
				}

				var sel = self.grid.get("selectionArray");
				var counter = sel.length;

				/* Clear the current messages on the screen */
				self.page.get("messageList").removeAll();

				sel.forEach(function(vpsId){
					console.log("I'm trying to delete VPS with id = [" + vpsId + "]");

					/* Remove the VPS from the APS controller DB */
					when(store.remove(vpsId),
						 /* If success, process the next VPS until the list is empty */
						function(){
							console.log("VPS with id = [" + vpsId + "] removed");
							sel.splice(sel.indexOf(vpsId),1);
							self.grid.refresh();
							if (--counter === 0) { btn.cancel(); }
						},
						/* If failure, call the error handler */
						function(e){
							displayError(e);
							if (--counter === 0) { btn.cancel(); }
						}
					);
				});
			};

			/* Declare and return widgets */
			return ["aps/Grid", {
					id:                "srv_grid",
					store:             store,
					selectionMode:     "multiple",
					apsResourceViewId: "server-edit",
					columns:           [
						{
							field: "name",
							name: "Name",
							type: "resourceName"
						},
						{
							field: "domainName",
							name: "Domain"
						},
						{
							field: "cnameRecord",
							name: "CNAME",
							type: "icon",
							renderCell: function(row, cnameRecord) {
								return new Status({
									status: cnameRecord,
									useIcon: true,
									statusInfo: {
										"false": {
											"label": "",
											"type": "default"
										},
										"true": {
											"label": "",
											"type": "success"
										}
								   }
								});
							  }
						},
						{
							field: "hardware.memory",
							name: "RAM"
						},
						{
							field: "hardware.diskspace",
							name: "Disk Space"
						},
						{
							field: "hardware.CPU.number",
							name: "CPU"
						},
						{
							field: "platform.OS.name",
							name: "OS"
						},
						{
							field: "state",
							name: "State"
						}
					]
				}, [
					["aps/Toolbar", [
						["aps/ToolbarButton", {
							id: "srv_new",
							iconClass:"fa-plus",
							type: "primary",
							label: "New",
							autoBusy: false,
							size: 3,
							onClick: add
						}],
						["aps/ToolbarButton", {
							id: "srv_start",
							iconClass:"fa-play",
							type: "success",
							label: "Start",
							autoBusy: false,
							requireItems: true,
							size: 3,
							onClick: start
						}],
						["aps/ToolbarButton", {
							id: "srv_stop",
							iconClass:"fa-pause",
							type: "warning",
							label: "Stop",
							autoBusy: false,
							requireItems: true,
							size: 3,
							onClick: stop
						}],
						["aps/ToolbarButton", {
							id: "srv_delete",
							iconClass:"fa-trash",
							type: "danger",
							label: "Delete",
							autoBusy: false,
							requireItems: true,
							size: 3,
							onClick: remove
						}],
						["aps/ToolbarButton", {
							id: "srv_refresh",
							iconClass:"fa-refresh",
							label: "Refresh",
							autoBusy: false,
							size: 3,
							onClick: refresh
						}]
					]]
				]];
		},

		onContext: function() {
			this.grid = this.byId("srv_grid");
			this.page = this.byId("apsPageContainer");
			this.grid.refresh();
			aps.apsc.hideLoading();
		},

		onHide: function() {
			this.byId("srv_new").cancel();
		}

	});
});
